Learn R Programming

bayestransmission (version 0.1.0)

InsituParams: InSitu Parameters

Description

InSitu Parameters

Usage

InsituParams(probs = NULL, priors = NULL, doit = NULL, nstates = NULL)

Value

A list of parameters for in situ testing.

Arguments

probs

The probability of the individual being in each state.

priors

The prior probability of the individual being in each state.

doit

A flag indicating if the rate(s) should be updated in the MCMC.

nstates

The number of states (2 or 3). If NULL, inferred from probs length. For 2-state models, uses c(uncolonized, latent=0, colonized). For 3-state models, uses c(uncolonized, latent, colonized).

Examples

Run this code
InsituParams()
InsituParams(nstates = 2)  # c(0.9, 0.0, 0.1)
InsituParams(nstates = 3)  # c(0.98, 0.01, 0.01)

Run the code above in your browser using DataLab