Learn R Programming

bayestransmission (version 0.1.0)

OutOfUnitInfectionParams: Out of Unit Infection Parameters

Description

Out of Unit Infection Parameters

Usage

OutOfUnitInfectionParams(
  acquisition = Param(0.05),
  clearance = Param(0.01),
  progression = Param(0)
)

Value

A list of parameters for out of unit infection.

Arguments

acquisition

Rate of acquisition of the disease moving into latent state.

clearance

Rate of clearance of the disease moving into uncolonized state.

progression

Rate of progression of the disease moving into colonized state.

Examples

Run this code
OutOfUnitInfectionParams()

Run the code above in your browser using DataLab