The probability of the individual being in each state.
priors
The prior probability of the individual being in each state.
doit
A flag indicating if the rate(s) should be updated in the MCMC.
nstates
The number of states (2 or 3). If NULL, inferred from probs length.
For 2-state models, uses c(uncolonized, latent=0, colonized).
For 3-state models, uses c(uncolonized, latent, colonized).