Acquisition parameters for LinearAbxModel and LinearAbxModel2.
LinearAbxAcquisitionParams(
base = Param(0.001),
time = Param(1, 0),
mass = Param(1, 1),
freq = Param(1, 1),
col_abx = Param(1, 0),
suss_abx = Param(1, 0),
suss_ever = Param(1, 0)
)A list of parameters for acquisition.
The base rate of acquisition.
The time effect on acquisition.
The mass action effect on acquisition.
The frequency effect on acquisition.
The effect for colonized on antibiotics.
The effect on susceptible being currently on antibiotics.
The effect on susceptible ever being on antibiotics.
The model for this acquisition model is given by
$$ P(\mathrm{Acq(t)}) = \left[e^{\beta_\mathrm{time}(t-t_0)}\right]\\ \left\{e^{\beta_0} \left[ \left( \frac{\beta_\mathrm{freq}}{P(t)}+(1 - e^{\beta_\mathrm{freq}}) \right) e^{\beta_\mathrm{mass}}\left( (N_c(t) - N_{ca}(t)) + e^{\beta_\mathrm{col\_abx}}N_{ca}(t) \right) + 1 - e^{\beta_\mathrm{mass}} \right] \right\}\\ \left[ N_S(t) - N_E(t) + e^{\beta_\mathrm{suss\_ever}} \left( \left( E_i(t) - A_i(t) \right) + A_i(t)e^{\beta_\mathrm{suss\_abx}} \right) \right] $$ where P(Acq(t)) is the acquisition probability at time t, with effects from time (beta_time), mass action (beta_mass), frequency dependence (beta_freq), colonized individuals on antibiotics (beta_col_abx), and susceptible individuals currently (beta_suss_abx) or ever (beta_suss_ever) on antibiotics.