powered by
Out of Unit Infection Parameters
OutOfUnitInfectionParams( acquisition = Param(0.05), clearance = Param(0.01), progression = Param(0) )
A list of parameters for out of unit infection.
Rate of acquisition of the disease moving into latent state.
Rate of clearance of the disease moving into uncolonized state.
Rate of progression of the disease moving into colonized state.
OutOfUnitInfectionParams()
Run the code above in your browser using DataLab