SurveillanceTestParams: Surveillance Test Parameters
Description
Specify the rates of positive tests for each state of the model.
Usage
SurveillanceTestParams(
colonized = Param(init = 0.8, weight = 1),
uncolonized = Param(init = 1e-10, weight = 0),
latent = Param(init = 0, weight = 0)
)
Value
A list of parameters for surveillance testing.
Arguments
- colonized
Also known as the true positive rate for a two state model.
- uncolonized
Also known as the false positive rate for a two state model.
- latent
The rate of positive tests when the individual is in the (optional) latent state.